<?PHP
/**
 * Constains lists for resolving literal closer location types to the expected
 * ones.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out closer location types.
 */
final class MDConcCloserLocationTypes implements MDImporterConcordanceListInterface {

    private const LOCATION_TYPES_VERBOSE = [

        # Place of recording
        "" => "0",
        "0" => "0",

        # Place of recording
        "1" => "1",
        "Place of recording" => "1",

        # Finding place
        "2" => "2",
        "Fundort" => "2",
        "Place of discovery" => "2",
        "Lelőhely" => "2",

        # Former place
        "3" => "3",
        "Former place" => "3",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::LOCATION_TYPES_VERBOSE[$input])) {
            throw new MDImporterMissingConcordance("Unknown location type: " . $input);
        }

        return self::LOCATION_TYPES_VERBOSE[$input];

    }
}
