<?PHP
/**
 * Constains lists for grouping marking types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out marking types.
 */
final class MDConcMarkingType implements MDImporterConcordanceListInterface {

    private const MARKING_TYPES_VERBOSE = [

        // Default: Handwritten
        "-" => "handwritten",
        "x" => "handwritten",
        "schwarz" => "handwritten",
        "braun" => "handwritten",
        "Leinenarbeit" => "handwritten",
        "oben, Mitte, unten" => "handwritten",
        "graphisches Dekor" => "handwritten",
        "Abbild" => "handwritten",
        "Karikatur" => "handwritten",
        "Signatur" => "handwritten",
        "Relief" => "handwritten",
        "hersteller" => "handwritten",
        "mit braunem Leinen überzogen" => "handwritten",
        "mit grünem Papier überzogen" => "handwritten",
        "mit weißen Papier überzogen" => "handwritten",
        "schwarz bedruckten Leinen" => "handwritten",
        "rot gemasert" => "handwritten",
        "ornamentiert" => "handwritten",
        "handschriftlich; aufgeklebt" => "handwritten",

        # Handwriting

        "aufgemalt/geschrieben" => "handwritten",
        "Aufschrift" => "handwritten",
        "Aufschrift (Bleistift)" => "handwritten",
        "Aufschrift mit Tinte" => "handwritten",
        "beschrieben" => "handwritten",
        "beschriftet" => "handwritten",
        "Beschriftet" => "handwritten",
        "Bezeichnung" => "handwritten",
        "Bezeichnung in schwarzer Tusche" => "handwritten",
        "Bezeichnung in schwarzer Tusche und Blei" => "handwritten",
        "Bildaufschrift" => "handwritten",
        "blaue Kugelschreiberaufschrift" => "handwritten",
        "Bleistift" => "handwritten",
        "Bleisitft" => "handwritten",
        "Bleistiftbeschriftung" => "handwritten",
        "Bleistiftzeichnung" => "handwritten",
        "Bleistift,Kugelschreiber" => "handwritten",
        "Bleistift und Buntstift bzw. kann auch Tinte sein" => "handwritten",
        "Bleistiftbeschriftung auf der Rückseite" => "handwritten",
        "Bleistiftbeschriftungauf der Rückseite" => "handwritten",
        "Bleistiftbeschriftung vorn und hinten" => "handwritten",
        "Einkreisung mit wasserfestem Marker" => "handwritten",
        "ev. Tinte" => "handwritten",
        "Federtusche" => "handwritten",
        "Faserstift ?" => "handwritten",
        "Filzstiftnotiz" => "handwritten",
        "Füllerbeschriftung auf der Rückseite" => "handwritten",
        "Goldschrift" => "handwritten",
        "handschrifltich" => "handwritten",
        "Handschriftlich" => "handwritten",
        "handschriflich" => "handwritten",
        "handschriftlich" => "handwritten",
        "handschriftlich, Kleber" => "handwritten",
        "handschriftliche Notiz" => "handwritten",
        "handschriftlich + geklebt" => "handwritten",
        "handschriftlich, mit blauer Tinte" => "handwritten",
        "Handschriftlich mit Bleistift" => "handwritten",
        "Schrift" => "handwritten",
        "roter wasserfester Stift" => "handwritten",
        "keine Inschrift" => "handwritten",
        "Inschrift" => "handwritten",
        "Inschrift mit Bleistift" => "handwritten",
        "geschrieben" => "handwritten",
        "geschrieben (Kugelschreiber)" => "handwritten",
        "geschrieben (schwarzer Filzstift)" => "handwritten",
        "geschrieben mit schwarzer Ölfarbe" => "handwritten",
        "geschrieben mit schwarzer Farbe" => "handwritten",
        "Künstlersignatur" => "handwritten",
        "Kugelschreiber,Bleistift" => "handwritten",
        "Kugelschreiber" => "handwritten",
        "Kulibeschriftung auf der Rückseite" => "handwritten",
        "mit blauem Kugelschreiber beschriftet" => "handwritten",
        "mit blauem Kugelschreiber geschrieben" => "handwritten",
        "mit blauer Tinte signiert" => "handwritten",
        "mit Bleistift geschrieben" => "handwritten",
        "mit Bleistift signiert" => "handwritten",
        "mit Bleistift geschrieben, Notiz" => "handwritten",
        "mit Farbe geschrieben" => "handwritten",
        "mit Füller beschriftet" => "handwritten",
        "mit gelben Klebepunkten" => "handwritten",
        "mit Ölpastellstift geschrieben" => "handwritten",
        "mit schwarzem Stift geschrieben" => "handwritten",
        "mit schwarzer Tinte geschrieben" => "handwritten",
        "mit schwarzer tinte geschrieben" => "handwritten",
        "mit Tusche auf Holz geschrieben" => "handwritten",
        "mit Tinte geschrieben" => "handwritten",
        "Notiz" => "handwritten",
        "Notiz auf Notizblock" => "handwritten",
        "Notizen mit Bleistift" => "handwritten",
        "Nummerierung (roter Kugelschreiber)" => "handwritten",
        "Ölpastellstift geschrieben" => "handwritten",
        "Roter Stift" => "handwritten",
        "schwarze Filzstiftnotiz" => "handwritten",
        "schwarz geschrieben und glasiert" => "handwritten",
        "signiert und datiert" => "handwritten",
        "Signiert" => "handwritten",
        "signiert, mit Bleistift geschrieben" => "handwritten",
        "Signatur mit Kugelschreiber" => "handwritten",
        "signiert, mit blauer Tinte geschrieben" => "handwritten",
        "signiert, mit schwarzer Tinte geschrieben" => "handwritten",
        "Tinte" => "handwritten",
        "Tinte: schwarz" => "handwritten",
        "Tinte u. Kugelschreiber" => "handwritten",
        "Widmung in Tinte" => "handwritten",
        "Widmung mit schwarzer Tinte" => "handwritten",
        "Widmung mit blauer Tinte" => "handwritten",
        "Widmung mit weißer Tinte" => "handwritten",
        "Widmung mit roter Tinte" => "handwritten",

        "eingeschrieben" => "handwritten",
        "verschlungenes Monogramm" => "handwritten",

        # Scratchings
        "kratzen, Filzstift" => "scratch",
        "gekratzt" => "scratch",
        "eingeritztes Kreuzchen" => "scratch",
        "eingekratzt" => "scratch",
        "geschnitzt" => "scratch",
        "Glas geschliffen vom Boden bis zur Hälfte" => "scratch",
        "Scratching" => "scratch",

        # Overpaint
        "painted" => "painted",
        "Bemalung" => "painted",
        "bemalt" => "painted",
        "gemalt" => "painted",
        "signiert, gemalt" => "painted",

        # Glued
        "aufgeklebter Druck" => "glued",
        "Aufkleber" => "glued",
        "aufgeklebt" => "glued",
        "geklebt" => "glued",
        "Aufkleber weiß, rechteckig" => "glued",
        "Papieraufkleber" => "glued",
        "Abziehbild" => "glued",
        "Aufschrift auf aufgeklebtes Schildchen" => "glued",
        "aufgeklebtes Schild" => "glued",
        "Etikett" => "glued",   // This whole value doesn't make sense
        "Etiketten" => "glued",
        "etikettiert" => "glued",
        "Adressaufkleber des Voreigentümers" => "glued",

        "Blau gerändertes helles Etikett" => "glued",
        "Papieretikett, Klebeetikett" => "glued",
        "Links kleines Etikett; Kreide" => "glued",
        "Typenschild Alum." => "glued",
        "Messing-Typenschild" => "glued",
        "Kartoniert, mit schwarzem, genarbtem Papier überzogen" => "glued",

        # Cast (e.g. iron cast)
        "Guss" => "cast",
        "Guß" => "cast",
        "gegossen" => "cast",
        "eingegossen" => "cast",
        "mit eingegossen" => "cast",

        "Marke in Unterglasur- und Aufglasurmalerei" => "cast",
        "Passepartout" => "cast",

        # Printed
        "Druck" => "overprint",
        "gedruckt" => "overprint",
        "gedruckt; geklebt" => "overprint",
        "bedruckt" => "overprint",
        "bedruckt und Tinte" => "overprint",
        "aufgedruckt" => "overprint",
        "Gedruckt" => "overprint",
        "Tiefdruck" => "overprint",
        "Tiefdruck, weiß" => "overprint",
        "Aufdruck" => "overprint",
        "eingedruckt" => "overprint",
        "mit schwarzer Farbe bedruckt" => "overprint",
        "Druck und glasiert" => "overprint",
        "Druck, weiße Schrift" => "overprint",
        "gedruckt und geprägt" => "overprint",
        "gdruckt" => "overprint",
        "gerduckt" => "overprint",
        "goldener Druck mit Ornamenten und Zierrahmen" => "overprint",
        "Golddruck" => "overprint",
        "Seriennummer" => "overprint",
        "Textaufdruck" => "overprint",
        "gedruckt und gestempelt" => "overprint",
        "enthält Textaufdruck" => "overprint",
        "Preisangabe" => "overprint",
        "roter Aufdruck" => "overprint",
        "gestanzt und aufgedruckt" => "overprint",
        "Bibliotheksvermerk" => "overprint",
        "Firmenaufdruck" => "overprint",
        "Firmenaufdruck Namenseintrag" => "overprint",
        "Firmenaufdruck und Namenseintrag" => "overprint",
        "Daten und Formularnummer" => "overprint",
        "Farbaufdruck" => "overprint",
        "Goldaufdruck" => "overprint",
        "schwarzer Aufdruck" => "overprint",
        "schwwarzer Aufdruck" => "overprint",
        "geplottert" => "overprint",
        "gedruckt und eingeschoben" => "overprint",
        "gedruckt und eingeschoben, kursiv" => "overprint",
        "Druckerei-Vermerk" => "overprint",

        # Sewn
        "aufgestickt" => "sewn",
        "aufgenäht" => "sewn",
        "bestickter viereckiger Aufnäher" => "sewn",
        "eingestickt" => "sewn",
        "Fußsohle: gestickt, Fähnchen: angenäht" => "sewn",
        "gestickt/genäht" => "sewn",
        "gedruckt/genäht" => "sewn",
        "genäht" => "sewn",
        "maschinell gestickt bzw. aufgenähr" => "sewn",
        "maschinell gestickt bzw. aufgenäht" => "sewn",
        "schwarze Stickerei" => "sewn",

        # Burnt in
        "eingebrannt" => "burnt_in",
        "Brandstempel" => "burnt_in",
        "Brennstempel" => "burnt_in",

        # Stamped
        "stamped" => "stamp",
        "gestempelt" => "stamp",
        "Stempel (rund)" => "stamp",
        "Stempel" => "stamp",
        "blauer Stempel" => "stamp",
        "Eichstempel" => "stamp",
        "Eingangstempel (rot)" => "stamp",
        "Farbstempel" => "stamp",
        "Stempel,Kugelschreiber" => "stamp",
        "mit Metallstempel eingedrückt" => "stamp",
        "Marke" => "stamp",
        "Marke und Werbestempel" => "stamp",
        "Prägestempel" => "stamp",
        "Prägestempel des Fotografen" => "stamp",
        "roter Stempel" => "stamp",
        "schwarz gestempelt" => "stamp",
        "Stempelaufdruck" => "stamp",

        # Engraving
        "Gravur" => "engraving",
        "graviert" => "engraving",
        "Gravierung" => "engraving",
        "eingraviert" => "engraving",
        "aufgraviert" => "engraving",
        "graviert und gestempelt" => "engraving",
        "Nummer graviert, gedruckt" => "engraving",
        "eingraviert und geätzt" => "engraving",
        "Schnitt" => "engraving",

        # Screwed on
        "angeschraubt" => "screwed",
        "aufgeschraubt" => "screwed",
        "Schild aufgeschraubt" => "screwed",
        "Schild angeschraubt" => "screwed",
        "Messingschild angeschraubt" => "screwed",
        "Schild" => "screwed",
        "Herstellerschild" => "screwed",
        "Bleischild" => "screwed", # Kind of unclear
        "Messingschild" => "screwed",
        "Typenschild" => "screwed",
        "Blechschild" => "screwed",
        "Plaste-/Firmenschild" => "screwed",
        "ovales Messingschild" => "screwed",
        "ovales Blechschild (schwarz/silbern)" => "screwed",
        "ovales Messingschild, rot/silbern" => "screwed",
        "angeschraubter Beschlag, gedruckt ung eingeschoben" => "screwed",

        # Riveted
        "Angenietet" => "riveted",
        "Metallschild angenietet" => "riveted",

        # Embossing
        "geprägt" => "embossing",
        "geprägt und angeschraubt" => "embossing",
        "eingeprägt" => "embossing",
        "Prägung" => "embossing",
        "Stempel eingeprägt" => "embossing",
        "geflechelt" => "embossing",
        "Inschrift, geprägt" => "embossing",
        "schwarze Prägung" => "embossing",
        "aufgesetzt und genutet, eingeprägt" => "embossing",
        "mit eingeprägtem Golddruck" => "embossing",
        "geprägt im ovalen Stempel" => "embossing",
        "eingeprägt/gegossen" => "embossing",
        "Marke mit Stempel eingeschlagen" => "embossing",
        "geprägt auf Schleife" => "embossing",
        "eingeprägt, Umschrift um mittiges Löwen-Wappentier" => "embossing",
        "geprägt, Frakturschrift" => "embossing",
        "Goldprägung" => "embossing",
        "Golddruck und Prägung" => "embossing",
        "3 Marken mit Stempel eingeschlagen" => "embossing",
        "3 gleiche Marken mit Stempel nebeneinander eingeschlagen" => "embossing",
        "Marken mit Stempel eingeschlagen" => "embossing",
        "geprägt/Inschrift" => "embossing",
        "Geprägt/Inschrift" => "embossing",
        "geprägt/ Inschrift" => "embossing",
        "Inschrift/geprägt" => "embossing",
        "Inschrift/ geprägt" => "embossing",
        "Inschrift / geprägt" => "embossing",

        # Embroidery
        "gestickt" => "embroidered",
        "bestickt" => "embroidered",
        "maschinell gestickt" => "embroidered",
        "mit Goldfaden bestickt" => "embroidered",
        "Jugendstilornamente" => "embroidered",

        # Punched
        "gestanzt" => "punched",
        "geschlagen" => "punched",
        "gehämmert" => "punched",
        "eingestanzt" => "punched",
        "eingestanzt; ziseliert" => "punched",
        "gestanzt und bemalt" => "punched",

        # Scarified
        "geritzt" => "scarified",
        "eingeritzt" => "scarified",
        "handschliff" => "scarified",
        "Schliff" => "scarified",

        # Hallmarked
        "gepunzt" => "hallmarked",
        "eingepunzt" => "hallmarked",
        "gepunzt/gestanzt" => "hallmarked",
        "punziert" => "hallmarked",
        "getrieben und ziseliert" => "hallmarked",

        # Nailed
        "genagelt" => "nailed",
        "angenagelt" => "nailed",
        "eingenagelt" => "nailed",

        # Signature
        "signiert" => "signature",
        "farbig bemalt und glasiert" => "signature",
        "gemalt und glasiert" => "signature",

        # Watermark
        "Wasserzeichen" => "watermark",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::MARKING_TYPES_VERBOSE[$input])) {
            throw new MDImporterMissingConcordance("Unknown marking type: " . $input);
        }

        return self::MARKING_TYPES_VERBOSE[$input];

    }
}
