<?PHP
/**
 * Constains lists for grouping measurement types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Constains lists for grouping measurement types.
 */
final class MDConcMeasurementTypes implements MDImporterConcordanceListInterface {

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return MDMeasurementType|false
     */
    public static function getConcordanceTarget(string $input):MDMeasurementType|false {

        return match($input) {

            // Just list entries
            "Allgemein",
            "Passepartout",
            "Passepartout Standardformat",
            "Objektmaß",
            "Objektmass",
            "Außenmaß",
            "Außenmaß (Kiste)",
            "Bildmaß",
            "Bildmass",
            "Auflagekarton (Höhe x Breite)",
            "Passepartout Standardformat (Höhe x Breite)",
            "Blattmaß",
            "Blattmass",
            "m",
            "cm",
            "mm",
            "dm",
            "Spieldauer (h___m___s)",
            "Geschwindigkeit (Schallplatte)",
            "Geschwindigkeit (Band)",
            "Transportmaß (Breite x Höhe x Tiefe)",
            "Transportmaß (Breite x Höhe x Tiefe)Transportmaß (Breite x Höhe x Tiefe)",
            "Öffnung (Durchmesser)",
            "Kartonformat (Höhe x Breite)",
            "Negativformat (Breite x Lange)",
            "Passepartout (Höhe x Breite)",
            "Montage (Breite x Länge)",
            "Verpackungsmaß (Breite x Höhe x Tiefe)Verpackungsmaß (Breite x Höhe x Tiefe)",
            "Maße Transport (Höhe x Tiefe x Breite)",
            "Volumen",
            "Hohlmaß",
            "Buchformat",
            "Hohlmass",
            "Kaliber",
            "Zeit",
            "Original",
            "size",
            "base",
            "target",
            "Modell",
            "",
            "Plattengröße (Höhe x Breite)",
            "Sockel (Höhe x Tiefe x Breite)",
            "Sockel (Höhe x Tiefe x                                    Breite)",
            "Außenmaß (Höhe x Tiefe x Breite)",
            "Fläche",
            "Tafelmaß",
            "Tafelmass",
            "Bemalte Fläche",
            "Bemalte Bildfläche",
            "Sockel",
            "Höhe x                                    Breite",
            "Höhe x                                    Durchmesser",
            "Rahmenmaß (Höhe x
                                    Breite)",
            "Höhe x Breite x                                    Tiefe",
            "Höhe x Breite x Tiefe",
            "Rahmenmaß",
            "Rahmenmaß (Höhe x Breite)",
            "Rahmenmaß (Höhe x                                    Breite)",
            "Rahmenmass",
            "Rahmenmass (Höhe x Breite)",
            "Rahmenaußenmaß (Höhe x Breite)",
            "Rahmenaußenmaß (Länge x Durchmesser)",
            "Höhe x Breite x Stärke",
            "Rahmenaußenmaß",
            "Rahmenaußenmass",
            "Kartonformat",
            "Kartonformat (Foto)",
            "Auflagekarton",
            "Bildformat (Foto)",
            "Tafelmaß (Höhe x Breite)",
            "Bemalte Bildfläche (Höhe x Breite)",
            "Plattengröße (Foto)",
            "Andere Maße",
            "Format",
            "Stichhöhe",
            "Maße Transport",
            "Länge x Breite x Höhe",
            "Länge x Breite x                                    Tiefe",
            "Länge x                                    Breite",
            "Maße Transport (Höhe x Tiefe x                                    Breite)",
            "Blattmaß (Höhe x Breite)",
            "Objektmaß (Höhe x Tiefe x Breite)",
            "Objektmaß (Höhe x Tiefe x                                    Breite)",
            "Teil 1",
            "Teil 2",
            "Teil 3",
            "Teil 4",
            "Teil 5",
            "Teil 6",
            "Teil 7",
            "Teil 8",
            "Kistenmaß (Länge x Breite x Höhe)",
            "Umfang",
            "Länge x Breite",
            "Bildmaß (Höhe x Breite)",
            "Bildformat (Höhe x Breite)",
            "Glasmaß (Höhe x Breite)",
            "Länge x Breite x Tiefe",
            "Höhe x Durchmesser",
            "Länge x Durchmesser",
            "Breite x Höhe",
            "Breite x Höhe x Tiefe",
            "Breite x                                    Höhe",
            "Breite x Tiefe",
            "Höhe x Breite",
            "Höhe x Breite (aufgeschlagen)",
            "Höhe x Breite x Tiefe",
            "Durchmesser x Tiefe",
            "Durchmesser x                                    Tiefe",
            "Gesamtmaß (Höhe x Breite x Tiefe)",
            "Form",
            "Andere",
            "HxBxT",
            "Stichhöhe (Höhe x Breite)" => false,

            "Höhe",
            "height",
            "Außenmaß (Höhe)",
            "Reliefhöhe" => MDMeasurementType::height,

            "Länge",
            "length",
            "Tiefe",
            "Teife",
            "length",
            "depth",
            "Dicke" => MDMeasurementType::length,

            "Breite",
            "width",
            "Außenmaß (Breite)",
            "Schenkelbreite (Breite)" => MDMeasurementType::width,

            "Durchmesser",
            "Durchm.",
            "Durchmesser (mit Dicke)",
            "Durchmesser (Boden)",
            "Mündung (Durchmesser)",
            "Rahmenaußenmaß Durchmesser",
            "diameter",
            "Durchmesser in Richtung Bohrung",
            "Durchmesser quer zur Bohrung",
            "d",
            "Ø" => MDMeasurementType::diameter,


            "width of wall",
            "Wandstärke (Durchmesser)" => MDMeasurementType::wall,

            "weight",
            "Gewicht" => MDMeasurementType::weight,


            "number of pages",
            "Seitenzahl",
            "Paginierung" => MDMeasurementType::number_of_pages,

            "Die Axis",
            "die-axis",
            "orientation",
            "Stempelstellung" => MDMeasurementType::die_axis,

            default => throw new MDImporterMissingConcordance("Unmapped specific measurement type: " . $input),

        };

    }
}
